==> vscat-1.0.0.tgz: package/tests/highlighting/diagnostics/html/tag-hint/results/output.kimbie-dark.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`diagnostics suite html language tag-hint test kimbie-dark theme 1`] = `
Object {
  "lines": Array [
    "[48;2;34;26;15m [38;2;133;133;133m 1 │ [39m[38;2;211;175;134m<[39m[38;2;220;57;88mhtml[39m[38;2;211;175;134m>[39m                                                                    [49m",
    "[48;2;34;26;15m [38;2;133;133;133m 2 │ [39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;211;175;134m<[39m[38;2;220;57;88mhead[39m[38;2;211;175;134m>[39m                                                                  [49m",
    "[48;2;34;26;15m [38;2;133;133;133m 3 │ [39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;211;175;134m<[39m[38;2;220;57;88mmeta[39m[38;2;165;122;76m·[39m[38;2;247;154;50mfoo[39m[38;2;211;175;134m=[39m[38;2;211;175;134m\\"[39m[38;2;136;155;74mbar[39m[38;2;211;175;134m\\"[39m[38;2;165;122;76m·[39m[38;2;211;175;134m/>[39m                                                    [49m",
    "[48;2;34;26;15m   [38;2;133;133;133m │ [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;165;122;76m [39m[38;2;166;166;166m~~~[39m                                                             [49m",
    "[48;2;34;26;15m [38;2;133;133;133m 4 │ [39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;211;175;134m<[39m[38;2;220;57;88mmeta[39m[38;2;165;122;76m·[39m[38;2;247;154;50mcharset[39m[38;2;211;175;134m=[39m[38;2;211;175;134m\\"[39m[38;2;136;155;74mutf-8[39m[38;2;211;175;134m\\"[39m[38;2;165;122;76m·[39m[38;2;211;175;134m/>[39m                                              [49m",
    "[48;2;34;26;15m [38;2;133;133;133m 5 │ [39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;211;175;134m<[39m[38;2;220;57;88mtitle[39m[38;2;211;175;134m>my[39m[38;2;165;122;76m·[39m[38;2;211;175;134mpage</[39m[38;2;220;57;88mtitle[39m[38;2;211;175;134m>[39m                                                [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #D3AF86 │ <
 0 │  1, 5 │ #DC3958 │ html
 0 │  5, 6 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 3 │ #D3AF86 │   <
 1 │  3, 7 │ #DC3958 │ head
 1 │  7, 8 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 5 │ #D3AF86 │     <
 2 │  5, 9 │ #DC3958 │ meta
 2 │  9,10 │ #D3AF86 │  
 2 │ 10,13 │ #F79A32 │ foo
 2 │ 13,14 │ #D3AF86 │ =
 2 │ 14,15 │ #D3AF86 │ \\"
 2 │ 15,18 │ #889B4A │ bar
 2 │ 18,19 │ #D3AF86 │ \\"
 2 │ 19,22 │ #D3AF86 │  />
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 5 │ #D3AF86 │     <
 3 │  5, 9 │ #DC3958 │ meta
 3 │  9,10 │ #D3AF86 │  
 3 │ 10,17 │ #F79A32 │ charset
 3 │ 17,18 │ #D3AF86 │ =
 3 │ 18,19 │ #D3AF86 │ \\"
 3 │ 19,24 │ #889B4A │ utf-8
 3 │ 24,25 │ #D3AF86 │ \\"
 3 │ 25,28 │ #D3AF86 │  />
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 5 │ #D3AF86 │     <
 4 │  5,10 │ #DC3958 │ title
 4 │ 10,20 │ #D3AF86 │ >my page</
 4 │ 20,25 │ #DC3958 │ title
 4 │ 25,26 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 4 │ #D3AF86 │   </
 5 │  4, 8 │ #DC3958 │ head
 5 │  8, 9 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 3 │ #D3AF86 │   <
 6 │  3, 7 │ #DC3958 │ body
 6 │  7, 8 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0,11 │ #D3AF86 │     Content
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #D3AF86 │   </
 8 │  4, 8 │ #DC3958 │ body
 8 │  8, 9 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 2 │ #D3AF86 │ </
 9 │  2, 6 │ #DC3958 │ html
 9 │  6, 7 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/diagnostics/html/tag-hint/results/output.kimbie-dark.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`diagnostics suite html language tag-hint test kimbie-dark theme 1`] = `
Object {
  "lines": Array [
    "[48;2;34;26;15m [38;2;133;133;133m 1 │ [39m[38;2;211;175;134m<[39m[38;2;220;57;88mhtml[39m[38;2;211;175;134m>[39m                                                                    [49m",
    "[48;2;34;26;15m [38;2;133;133;133m 2 │ [39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;211;175;134m<[39m[38;2;220;57;88mhead[39m[38;2;211;175;134m>[39m                                                                  [49m",
    "[48;2;34;26;15m [38;2;133;133;133m 3 │ [39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;211;175;134m<[39m[38;2;220;57;88mmeta[39m[38;2;165;122;76m·[39m[38;2;247;154;50mfoo[39m[38;2;211;175;134m=[39m[38;2;211;175;134m\\"[39m[38;2;136;155;74mbar[39m[38;2;211;175;134m\\"[39m[38;2;165;122;76m·[39m[38;2;211;175;134m/>[39m                                                    [49m",
    "[48;2;34;26;15m   [38;2;133;133;133m │ [39m[38;2;211;175;134m          [39m[38;2;166;166;166m~~~[39m                                                             [49m",
    "[48;2;34;26;15m [38;2;133;133;133m 4 │ [39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;211;175;134m<[39m[38;2;220;57;88mmeta[39m[38;2;165;122;76m·[39m[38;2;247;154;50mcharset[39m[38;2;211;175;134m=[39m[38;2;211;175;134m\\"[39m[38;2;136;155;74mutf-8[39m[38;2;211;175;134m\\"[39m[38;2;165;122;76m·[39m[38;2;211;175;134m/>[39m                                              [49m",
    "[48;2;34;26;15m [38;2;133;133;133m 5 │ [39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;165;122;76m·[39m[38;2;211;175;134m<[39m[38;2;220;57;88mtitle[39m[38;2;211;175;134m>my[39m[38;2;165;122;76m·[39m[38;2;211;175;134mpage</[39m[38;2;220;57;88mtitle[39m[38;2;211;175;134m>[39m                                                [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #D3AF86 │ <
 0 │  1, 5 │ #DC3958 │ html
 0 │  5, 6 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 3 │ #D3AF86 │   <
 1 │  3, 7 │ #DC3958 │ head
 1 │  7, 8 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 5 │ #D3AF86 │     <
 2 │  5, 9 │ #DC3958 │ meta
 2 │  9,10 │ #D3AF86 │  
 2 │ 10,13 │ #F79A32 │ foo
 2 │ 13,14 │ #D3AF86 │ =
 2 │ 14,15 │ #D3AF86 │ \\"
 2 │ 15,18 │ #889B4A │ bar
 2 │ 18,19 │ #D3AF86 │ \\"
 2 │ 19,22 │ #D3AF86 │  />
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 5 │ #D3AF86 │     <
 3 │  5, 9 │ #DC3958 │ meta
 3 │  9,10 │ #D3AF86 │  
 3 │ 10,17 │ #F79A32 │ charset
 3 │ 17,18 │ #D3AF86 │ =
 3 │ 18,19 │ #D3AF86 │ \\"
 3 │ 19,24 │ #889B4A │ utf-8
 3 │ 24,25 │ #D3AF86 │ \\"
 3 │ 25,28 │ #D3AF86 │  />
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 5 │ #D3AF86 │     <
 4 │  5,10 │ #DC3958 │ title
 4 │ 10,20 │ #D3AF86 │ >my page</
 4 │ 20,25 │ #DC3958 │ title
 4 │ 25,26 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 4 │ #D3AF86 │   </
 5 │  4, 8 │ #DC3958 │ head
 5 │  8, 9 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 3 │ #D3AF86 │   <
 6 │  3, 7 │ #DC3958 │ body
 6 │  7, 8 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0,11 │ #D3AF86 │     Content
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #D3AF86 │   </
 8 │  4, 8 │ #DC3958 │ body
 8 │  8, 9 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 2 │ #D3AF86 │ </
 9 │  2, 6 │ #DC3958 │ html
 9 │  6, 7 │ #D3AF86 │ >
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │ none  │         │
",
  ],
}
`;
